/*
 * chunkfs.h - header file for chunkfs passes in the fsck
 *
 * Copyright (C) 2006 Amit Gud <gud@ksu.edu>
 */

#ifndef _CHUNKFS_H
#define _CHUNKFS_H

#define CHUNKFS_DEBUG

#ifdef CHUNKFS_DEBUG
#define chunkfs_dbg(fmt, arg...) \
	do { \
		printf("%s: " fmt "\n", __FUNCTION__,  ## arg); \
	} while(0)
#else
#define chunkfs_dbg(fmt, arg...) \
		do { } while(0)
#endif


#define CHUNK_ID(inode) (CHUNK_SB((inode)->i_sb)->s_chunk_id)
#define CHUNKFS_INO_MASK 0x00ffffff             /* ino's first byte indicates chunk number
						   and rest is the actual inode number */
#define DECODE_CID(ino) ((ino) >> 24)
#define DECODE_INO(ino) ((ino) & CHUNKFS_INO_MASK)
#define ENCODE_CNODE(cid, ino) (((cid) << 24) | (ino))

#define EXT2_HAS_CONT_FL		0x00040000 /* inode has a continuation inode */
#define EXT2_IS_CONT_FL			0x00080000 /* inode is a continuation inode */

typedef struct chunkfs_inode_list {
	union {
		struct {
			ext2_ino_t ino;
			ext2_ino_t parent;
		};
		ext2_ino_t count;
	};
	struct chunkfs_inode_list *next, *prev;
} cnode_list_t;

struct chunk_fsck_ctx {
	int			chunkid;
	struct e2fsck_struct	*ctx;
};

#endif /* _CHUNKFS_H */

